<?php

declare(strict_types=1);

namespace Drupal\jsonapi_links\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Configure JSON:API settings for this site.
 */
class SettingsForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId(): string {
    return 'jsonapi_links_settings';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames(): array {
    return [
      'jsonapi_links.settings',
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state): array {
    $config = $this->config('jsonapi_links.settings');

    $form = [];

    $form['remove_links'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Remove links attributes'),
      '#description' => $this->t('Links attributes will be removed recursively, except for the /jsonapi response and the ignore list.'),
      '#default_value' => $config->get('remove_links'),
    ];

    $form['ignore_list'] = [
      '#type' => 'textarea',
      '#title' => $this->t('Ignore list (regex to match to keep links attributes)'),
      '#description' => $this->t('Because some modules may define useful *links* sections, you can specify sections to ignore. Specify one entry per line. Example: "/jsonapi\.foo\.bar/". Each line must be a valid PHP RegEx. Array structures are supported like this: "/foo\.[0-9]+\.bar/"'),
      '#default_value' => $config->get('ignore_list'),
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state): void {
    $config = $this->config('jsonapi_links.settings');

    $keys = [
      'remove_links',
      'ignore_list',
    ];

    foreach ($keys as $key) {
      $config->set($key, $form_state->getValue($key));
    }

    $config->save();
  }

}
